<?php
/**
* @link              	http://www.contentengine.net/
* @since             	1.2022.12.22
* @package           	evt-content-engine
*
* @wordpress-plugin
* Plugin Name:       	EVT Content Engine
 * Plugin URI:        	https://www.contentengine.net/wordpress-plugin/
* Description:       	Custom B2B News Feeds - Integrates the EVT Content Engine into WordPress [Settings can be found under 'EVT Content' link in WP-Admin 'Plugins' sidebar menu.]
* Version:           	1.2022.12.22
* Author:            	Content Engine Marketing, Inc.
* Author URI:        	http://www.contentengine.net/
* License:           	EVT
 * License URI:       	https://www.contentengine.net/eula/
* Requires at least: 	2.8.0
* Tested up to: 		6.1.1
*/


###############################################################################################################################################################
//		CONSTANTS
###############################################################################################################################################################

define("EVT_MAX_DAYS", 	8);
define("EVT_MIN_DAYS", 	3);
define('EVT_MAX_LIMIT',	50);

###############################################################################################################################################################
//		PREVENT DIRECT ACCESS
###############################################################################################################################################################
if ( ! defined( 'WPINC' ) ) {
	 die;
}

###############################################################################################################################################################
//		ACTIVATE PLUG-IN
###############################################################################################################################################################

register_activation_hook(__FILE__, 'evt_content_engine_activate_plugin');
function evt_content_engine_activate_plugin() {

	// CHECK IF CRON IS ALREADY SCHEDULED, SET SCHEDULER FOR AUTOMATED API UPDATES
	if ( ! wp_next_scheduled ( 'evt_content_engine_update' )) {
		wp_schedule_event( strtotime('11:00:00 UTC'), 'daily', 'evt_content_engine_update' );
    }
}
add_action('evt_content_engine_update','evt_content_engine_call_API');


###############################################################################################################################################################
//		DEACTIVATE PLUG-IN
###############################################################################################################################################################

register_deactivation_hook(__FILE__, 'evt_content_engine_deactivate_plugin');
function evt_content_engine_deactivate_plugin() {

	update_option('evt_content_engine_last_update', 			'0' );
	update_option('evt_content_engine_processing_update', 		'0' );
	update_option('evt_content_engine_status', 					'' );

	wp_clear_scheduled_hook('evt_content_engine_update');
}


###############################################################################################################################################################
//		ENQUEUE CSS & JS FILES
###############################################################################################################################################################
function evt_content_engine_add_css() {

    //wp_register_style( 'evt_content_engine_css',  plugin_dir_url( __FILE__ ) . 'css/evt-content-engine.css' );
    wp_register_style( 'evt_content_engine_css', 'https://cdn.contentengine.net/css/evt_content_engine.css' );
    wp_enqueue_style( 'evt_content_engine_css' );

    //wp_register_style( 'evt_social_share_css',  plugin_dir_url( __FILE__ ) . 'css/evt-social-share.css' );
    wp_register_style( 'evt_social_share_css',  'https://cdn.contentengine.net/css/evt-social-share.css' );
    wp_enqueue_style( 'evt_social_share_css' );

    wp_register_script( 'evt_csc_js' , 'https://cdn.contentengine.net/js/evt_csc.js' );
    wp_enqueue_script( 'evt_csc_js' );

    //wp_register_script( 'evt_social_share_js' , plugin_dir_url( __FILE__ ) . 'js/evt-social-share.js' );
    wp_register_script( 'evt_social_share_js' , 'https://cdn.contentengine.net/js/evt-social-share.js' );
    wp_enqueue_script( 'evt_social_share_js' );

}

add_action( 'wp_enqueue_scripts', 'evt_content_engine_add_css', 30 );



###############################################################################################################################################################
//		INCREASE CURL TIMEOUT
###############################################################################################################################################################

add_filter('http_request_args', 'bal_http_request_args', 100, 1);
function bal_http_request_args($r) //called on line 237
{
	$r['timeout'] = 30;
	$r['sslverify'] = false;
	return $r;
}

add_action('http_api_curl', 'bal_http_api_curl', 100, 1);
function bal_http_api_curl($handle) //called on line 1315
{
	curl_setopt( $handle, CURLOPT_CONNECTTIMEOUT, 30 );
	curl_setopt( $handle, CURLOPT_TIMEOUT, 30 );
	curl_setopt( $handle, CURLOPT_SSL_VERIFYPEER, FALSE);
}

###############################################################################################################################################################
//		LOAD NEWS FEED DATA FROM API ENDPOINT
###############################################################################################################################################################
function evt_content_engine_call_API() {

	$evt_settings 					= evt_content_engine_get_settings();
	$data_age_in_seconds 			= ( time() - $evt_settings['last_update'] );

	// MAKE SURE API CALL IS NOT ALREADY PROCESSING
	if(
		(isset($evt_settings['processing_update']) && $evt_settings['processing_update'] == '0') ||
		( isset($evt_settings['processing_update']) && $evt_settings['processing_update'] != '0' && ($data_age_in_seconds > (60*60*36)) && ($data_age_in_seconds < (60*60*24*14)) ) ||
		isset($_REQUEST['refresh'])
	) {

		// MAKE SURE ACCOUNT VID SETTING IS POPULATED AND LOOKS RIGHT
		if( isset($evt_settings['view_id']) && strlen($evt_settings['view_id']) == 40 ) {

			// SET processing_update FLAG
			update_option('evt_content_engine_processing_update', time() );

			// FORM API URL
			$api_url = 'https://api.contentengine.net/api.php?vid='.$evt_settings['view_id'].'&format=wp&images='.$evt_settings['images'].'&days='.$evt_settings['days'].'&limit='.$evt_settings['limit'];

			// CALL API
			$request = wp_remote_get($api_url);

			if( is_wp_error( $request ) ) {

				update_option('evt_content_engine_status', $request->get_error_message() );
				update_option('evt_content_engine_processing_update', '0' );
				return false;

			}

			$results = unserialize( wp_remote_retrieve_body( $request ) );

			if( $results['articles'] && count($results['articles']) > 0 ) {

				file_put_contents( plugin_dir_path(__FILE__).'data/package', wp_remote_retrieve_body( $request ) );

				// SET LAST UPDATED TIME
				update_option('evt_content_engine_last_update', $results['published_timestamp']);

				// SET STATUS TO 'Active - Working'
				update_option('evt_content_engine_status', 'Active - Working' );

				// UNSET processing_update FLAG
				update_option('evt_content_engine_processing_update', '0' );

				return true;

			} else {

				update_option('evt_content_engine_status', 'Invalid Account Status - Please contact us for assistance (www.contentengine.net)' );
				update_option('evt_content_engine_processing_update', '0' );
				return false;
			}
		}

		update_option('evt_content_engine_status', 'Please enter your <b>Feed ID</b> in the form below.' );

	}

	return false;

}


###############################################################################################################################################################
//		LOAD NEWS FEED DATA FROM LOCAL CACHE
###############################################################################################################################################################
function evt_content_engine_load_cache() {

	$evt_settings['last_update'] 	= get_option('evt_content_engine_last_update', 0);
	$data_age_in_seconds 			= ( time() - $evt_settings['last_update'] );

	// IF DATA IS OLD
	if( $evt_settings['last_update'] == 0 || ( ($data_age_in_seconds > (60*60*23)) && ($data_age_in_seconds < (60*60*24*14)) ) || isset($_REQUEST['refresh']) ) {
		update_option('evt_content_engine_status', 'Outdated Feed Data' );
		evt_content_engine_call_API();
	}

	if( file_exists(plugin_dir_path(__FILE__).'data/package')  ) {
		// evt_content_engine_call_API();
		return unserialize(file_get_contents(plugin_dir_path(__FILE__).'data/package'));
	}
}


###############################################################################################################################################################
//		NEWS FEED DISPLAY & SHORTCODE HOOK
###############################################################################################################################################################
function evt_content_engine_display() {

	// LOAD CACHED DATA OR FETCH DATA
	$data_array 					= evt_content_engine_load_cache();

	$evt_settings['images'] 		= get_option('evt_content_engine_images', 		'true');
	$evt_settings['view_id'] 		= get_option('evt_content_engine_view_id', 			'');
	$evt_settings['csc_group'] 		= get_option('evt_content_engine_csc_group', 		'');

	ob_start();

	// ENABLE SOCIAL SHARING DISPLAY?
	if(
		isset($data_array['social_sharing_active']) && $data_array['social_sharing_active'] == 'Y'
	) {
		$evt_social_sharing = true;
	} else {
		$evt_social_sharing = false;
	}

	if( isset($data_array['articles']) && count($data_array['articles']) > 0 ) {
	?>
	<div class="evt_articles_main">
		<div class="evt_articles_alignment">
		<hr class="evt_articles_hr">
		<?php

		foreach($data_array['articles'] as $row) {
			?>
				<div class="evt_articles_blockquote" aid="<?php echo $row['source_id'].':'.$row['article_dbid']?>">
					<div>
						<div class="evt_articles_title">
							<a href="<?php echo $row['article_url']?><?php echo evt_draw_utm($evt_settings)?>" target="_blank" class="evt_articles_link"><?php echo $row['article_title']?></a>
						</div>
						<?php if(isset($evt_settings['images']) && $evt_settings['images'] == 'true' && isset($row['article_image_base64']) && $row['article_image_base64'] != '') {
							$img_alt = ucwords(strtolower( preg_replace("/[\s]+/is", " ", preg_replace("/[^0-9A-Za-z\,\']/is", " ", join(" ", array_slice(array_keys($row['article_top_tokens']), 0, 6) ))) ));
							?>
							<img src="<?php echo plugin_dir_url(__FILE__)?>images/image.php?id=<?php echo $row['article_id']?>" class="evt_articles_thumbnail" alt="<?php echo $img_alt?>" title="<?php echo $img_alt?>">
						<?php } ?>
						<div class="evt_articles_excerpt"><span class="evt_articles_date_line"><?php echo  date("M jS, Y", strtotime($row['article_date']))?></span> - <?php echo $row['article_text']?> <a href="<?php echo $row['article_url']?><?php echo evt_draw_utm($evt_settings)?>" target="_blank">[Read More]</a></div>
					</div>
					<br class="evt_articles_clear_br"><!-- <?php echo $row['article_score']?> -->
					<?php if($evt_social_sharing) { ?>
					<div class="need-share-button-default" id="<?php echo $row['article_id']?>" data-date="<?php echo date("Ym", $row['article_timestamp'])?>" data-cid="<?php echo $data_array['vid'] ?>" data-title="<?php echo str_replace( '"', "'", $row['article_title'] )?>" data-tags="<?php echo join(',', array_slice(array_keys($row['article_top_tokens']), 0, 3) )?>" data-url="<?php echo $row['article_url']?><?php echo evt_draw_utm($evt_settings)?>"></div>
					<?php } ?>
					<div class="<?php if($evt_social_sharing) { echo "evt_articles_source_left"; } else { echo "evt_articles_source"; } ?>"><b>Source:</b> <a href="http://<?php echo $row['source_domain']?><?php echo evt_draw_utm($evt_settings)?>/" target="_blank"><?php echo $row['source_domain']?></a></div>
				</div>
				<hr class="evt_articles_hr">
			<?php
		}
		?>
		</div>
	</div>
	<script type="text/javascript">

		var evt_parameters = {
			vid:				'<?php echo $evt_settings['view_id'];?>',
			logging:			false,
			<?php if( isset($evt_settings['csc_group']) && $evt_settings['csc_group'] != '') { ?>group:				'<?php echo $evt_settings['csc_group'];?>',<?php } ?>
		};

		var evt_csc_var		= new evt_csc(evt_parameters);

	</script>
	<?php
	}

	$output = ob_get_clean();


	return $output;
}
add_shortcode('EVT-CONTENT-ENGINE', 'evt_content_engine_display');


###############################################################################################################################################################
//		GET ALL EVT-CONTENT-ENGINE SETTINGS/OPTIONS
###############################################################################################################################################################

function evt_content_engine_get_settings() {

	$evt_settings = array();

	// ACCOUNT ID
	$evt_settings['view_id'] 			= get_option('evt_content_engine_view_id', 				'');
	$evt_settings['csc_group'] 			= get_option('evt_content_engine_csc_group', 			'');

	// FEED DISPLAY SETTINGS
	$evt_settings['days'] 				= get_option('evt_content_engine_days', 				'8');
	$evt_settings['limit'] 				= get_option('evt_content_engine_limit', 				'10');
	$evt_settings['images'] 			= get_option('evt_content_engine_images', 				'true');

	// FEED STATUS & MESSAGES
	$evt_settings['last_update'] 		= get_option('evt_content_engine_last_update', 			'0');
	$evt_settings['processing_update'] 	= get_option('evt_content_engine_processing_update', 	'0');
	$evt_settings['status'] 			= get_option('evt_content_engine_status', 				'');

	return $evt_settings;

}


###############################################################################################################################################################
//		ADD WP-ADMIN SETTINGS PAGE TO ADMIN MENUS
###############################################################################################################################################################
function evt_content_engine_create_admin_menu() {
	add_plugins_page('EVT Content Engine - Settings', 'EVT Content', 'manage_options', 'evt-content-engine', 'evt_content_engine_admin_menu_display', '', 420);
}
add_action('admin_menu', 'evt_content_engine_create_admin_menu');


###############################################################################################################################################################
//		DISPLAY WP-ADMIN SETTINGS PAGE
###############################################################################################################################################################
function evt_content_engine_environment_check() {

	if( file_exists(plugin_dir_path(__FILE__).'data/package')  ) {
		//(plugin_dir_path(__FILE__).'data/package');
	}

}

###############################################################################################################################################################
//		DRAW UTM (IF NEEDED)
###############################################################################################################################################################

function evt_draw_utm($evt_settings, $include_question_mark=true) {
	
	 if( isset($evt_settings['csc_group']) && $evt_settings['csc_group'] != '') {
		return ($include_question_mark?'?':'').'utm_campaign='.$evt_settings['csc_group'].'&utm_medium=newsfeed&utm_source=CEM';
	 }
}

###############################################################################################################################################################
//		TEXT EXCERPT
###############################################################################################################################################################

function evt_excerpt($text, $max_length) {

	$result 	= '';
	$parts 		= explode(" ", $text);
	foreach($parts as $part) {
		if( strlen( $result.' '.$part ) <= $max_length ) {
			$result .= ' '.$part;
		} else {
			$result .= ' ...';
			break;
		}
	}
	return $result;
}

###############################################################################################################################################################
//		DISPLAY WP-ADMIN SETTINGS PAGE
###############################################################################################################################################################
function evt_content_engine_admin_menu_display() {

	if( isset($_POST['evt_content_engine_settings_submit']) ) {

		update_option('evt_content_engine_view_id', substr( preg_replace("/[^A-Z0-9]/", "", trim(strtoupper($_POST['evt_view_id']))), 0, 40));
		update_option('evt_content_engine_csc_group', substr( preg_replace("/[^A-Z0-9\_]/", "", trim(strtoupper($_POST['evt_csc_group']))), 0, 45));

		update_option('evt_content_engine_days', preg_replace("/[^0-9]/", "", (Int) $_POST['evt_days']));
		update_option('evt_content_engine_limit', preg_replace("/[^0-9]/", "", (Int) $_POST['evt_limit']));
		update_option('evt_content_engine_images', ($_POST['evt_images']=='true')?'true':'false');

		evt_content_engine_call_API();

		?><div id="setting-error-settings_updated" class="updated settings-error notice is-dismissible" style="line-height: 48px;">Settings updated</div><?php
	}

	$evt_settings = evt_content_engine_get_settings();

	?>
	<style type="text/css">

		.evt_container {
			padding: 			8px 12px;
		}

		.evt_container h3 {
			margin-top: 		18px;
			margin-bottom: 		6px;
			font-size:			1.1em;
		}

		.evt_container .evt_description {
			margin-bottom: 		8px;
		}

		.evt_container .evt_option {
			margin-bottom: 		26px;
		}

		.evt_container .evt_spacer {
			line-hight:			1px;
			margin:				12px 0px;
			border-bottom:		1px solid rgba(51, 51, 51, 0.1);
		}

		.evt_container .evt_required {
			font-size: 			13px;
			color: 				red;
			margin-left: 		0px;
		}

		.evt_container p {
			font-size: 			16px;
		}
	</style>
	<div class="wrap">
		<div class="evt_container">
			<h1>EVT Content Engine - Account and News Feed Settings</h1>

			<div class="evt_spacer"></div>
				<div class="evt_label">
					<h2>Plugin Status</h2>
				</div>
			<div class="evt_spacer"></div>
			<blockquote>
				<div class="evt_label">
					<h3>Last Update:</h3>
				</div>
				<div class="evt_description">
					<?php echo ($evt_settings['last_update'] == '0')?'Not updated':(date("F j, Y, h:i A", $evt_settings['last_update']).' UTC')?>
				</div>

				<div class="evt_label">
					<h3>Status Messages:</h3>
				</div>
				<div class="evt_description">
					<?php
						if( $evt_settings['processing_update'] != '0') {
							echo '<span class="evt_required">Update Process Started - '.date("F j, Y, h:i A", $evt_settings['processing_update']).' UTC</span>';
						} else {
							echo ($evt_settings['status'] == '')?'Please enter your <b>Feed ID</b> in the form below.':$evt_settings['status'];
						}
					?>
				</div>

				<div class="evt_label">
					<h3>Install Instructions:</h3>
				</div>
				<div class="evt_description">
					<a href="https://www.contentengine.net/wordpress-plugin/" target="_blank">https://www.contentengine.net/wordpress-plugin/</a>
				</div>

			</blockquote>
			<br>

			<form method="POST" action="">

				<div class="evt_spacer"></div>
					<div class="evt_label">
						<h2>Account Settings</h2>
					</div>
				<div class="evt_spacer"></div>

					<blockquote>
						<div class="evt_label">
							<h3>Feed ID <span class="evt_required">(required)</span></h3>
						</div>
						<div class="evt_description">Please enter your Feed ID.</div>
						<div class="evt_option">
							<input type="text" name="evt_view_id" value="<?php echo $evt_settings['view_id']?>" size="60">
						</div>
					</blockquote>
					<br>
					
					<blockquote>
						<div class="evt_label">
							<h3>Network ID <span class="evt_required">(required if part of a content distribution network)</span></h3>
						</div>
						<div class="evt_description">Please enter your Network ID.</div>
						<div class="evt_option">
							<input type="text" name="evt_csc_group" value="<?php echo $evt_settings['csc_group']?>" size="60">
						</div>
					</blockquote>
					<br>
					
				<div class="evt_spacer"></div>
					<div class="evt_label">
						<h2>News Feed Settings</h2>
					</div>
				<div class="evt_spacer"></div>

				<blockquote>

					<div class="evt_label">
						<h3>Number of News Entries (1 to <?php echo EVT_MAX_LIMIT?> news entries)</h3>
					</div>
					<div class="evt_description">The number of articles to display in the feed.</div>
					<div class="evt_option">
						<select name="evt_limit">
							<?php for($evt_x=1; $evt_x<=EVT_MAX_LIMIT; $evt_x++) { ?>
							<option value="<?php echo $evt_x; ?>" <?php if($evt_settings['limit'] == $evt_x) { echo " selected"; } ?>><?php echo $evt_x; ?></option>
							<?php } ?>
						</select>
					</div>

					<div class="evt_label">
						<h3>Max Age of News (<?php echo EVT_MIN_DAYS?> to <?php echo EVT_MAX_DAYS?> days)</h3>
					</div>
					<div class="evt_description">How many days of past news should be considered for inclusion in the feed.</div>
					<div class="evt_option">
						<select name="evt_days">
							<?php for($evt_x=EVT_MIN_DAYS; $evt_x<=EVT_MAX_DAYS; $evt_x++) { ?>
							<option value="<?php echo $evt_x; ?>" <?php if($evt_settings['days'] == $evt_x) { echo " selected"; } ?>><?php echo $evt_x; ?></option>
							<?php } ?>
						</select>
					</div>

					<div class="evt_label">
						<h3>Include Images</h3>
					</div>
					<div class="evt_description">Include images in the news feed?</div>
					<div class="evt_option">
						<select name="evt_images">
							<option value="true" <?php if($evt_settings['images'] == 'true') { echo " selected"; } ?>>Yes</option>
							<option value="false>" <?php if($evt_settings['images'] != 'true') { echo " selected"; } ?>>No</option>
						</select>
					</div>
				</blockquote>
				<br>

				<div class="evt_spacer"></div>
				<br><br>

				<div>
					<input type="submit" name="evt_content_engine_settings_submit" value="Save Settings" class="button button-primary">
				</div>
				<br><br><br><br>
			</form>
		</div>
	</div>
	<?php
}
?>